You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@whimsical.apache.org by ru...@apache.org on 2017/08/19 15:15:38 UTC

[whimsy] branch master updated (61e1e6b -> db0b733)

This is an automated email from the ASF dual-hosted git repository.

rubys pushed a change to branch master
in repository https://gitbox.apache.org/repos/asf/whimsy.git.


    from 61e1e6b  move back to trusty
     new f0975a0  handle server already stopped
     new db0b733  munch return-path too

The 2 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "add" were already present in the repository and have only
been added to this reference.


Summary of changes:
 tools/travis-relay.rb                 |  4 ++--
 www/board/agenda/spec/react_server.rb | 18 ++++++++++++------
 2 files changed, 14 insertions(+), 8 deletions(-)

-- 
To stop receiving notification emails like this one, please contact
['"commits@whimsical.apache.org" <co...@whimsical.apache.org>'].

[whimsy] 02/02: munch return-path too

Posted by ru...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

rubys pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/whimsy.git

commit db0b733d3062bdf2485e79227ce5be29dd6b08e4
Author: Sam Ruby <ru...@intertwingly.net>
AuthorDate: Sat Aug 19 11:15:24 2017 -0400

    munch return-path too
---
 tools/travis-relay.rb | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

-- 
To stop receiving notification emails like this one, please contact
"commits@whimsical.apache.org" <co...@whimsical.apache.org>.

[whimsy] 01/02: handle server already stopped

Posted by ru...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

rubys pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/whimsy.git

commit f0975a07871d997dbcb690025c8bd0a67d5c6bf6
Author: Sam Ruby <ru...@intertwingly.net>
AuthorDate: Sat Aug 19 11:13:27 2017 -0400

    handle server already stopped
---
 www/board/agenda/spec/react_server.rb | 18 ++++++++++++------
 1 file changed, 12 insertions(+), 6 deletions(-)

diff --git a/www/board/agenda/spec/react_server.rb b/www/board/agenda/spec/react_server.rb
index acec0b4..0da16b4 100644
--- a/www/board/agenda/spec/react_server.rb
+++ b/www/board/agenda/spec/react_server.rb
@@ -55,12 +55,18 @@ class ReactServer
   # stop server
   def self.stop
     return unless @@pid
-    http = Net::HTTP.new('localhost', @@port)
-    request = Net::HTTP::Post.new('/', {})
-    request.body = "response.end('bye'); process.exit(0)"
-    response = http.request(request)
-    Process.wait(@@pid)
-    @@pid = nil
+
+    begin
+      http = Net::HTTP.new('localhost', @@port)
+      request = Net::HTTP::Post.new('/', {})
+      request.body = "response.end('bye'); process.exit(0)"
+      response = http.request(request)
+    rescue Errno::ECONNREFUSED
+      nil
+    ensure
+      Process.wait(@@pid)
+      @@pid = nil
+    end
   end
 
   # the server itself

diff --git a/tools/travis-relay.rb b/tools/travis-relay.rb
index 4e380e9..9652b9e 100644
--- a/tools/travis-relay.rb
+++ b/tools/travis-relay.rb
@@ -3,11 +3,11 @@
 #
 # 'To' header will be replaced
 # 'From' header will effectively be replaced
 # Transport headers names will be prepended with 'X-'
 # Original content headers will be dropped (and recreated).
 #
 
-munge = %w(received delivered-to)
+munge = %w(received delivered-to return-path)
 skip = %w(content-type content-transfer-encoding)
 
 $LOAD_PATH.unshift File.expand_path('../../lib', __FILE__)
@@ -3,11 +3,11 @@
 # 'To' header will be replaced
 # 'From' header will effectively be replaced
-# Transport headers names will be prepended with 'X-'
+# Transport and return path headers names will be prepended with 'X-'
 # Original content headers will be dropped (and recreated).
 #

-- 
To stop receiving notification emails like this one, please contact
"commits@whimsical.apache.org" <co...@whimsical.apache.org>.